@@ -196,12 +196,12 @@ public_key_blob(EC_KEY *key)
 	if (key == NULL || (length = public_key_length(key)) <= 0)
 		return NULL;
 
-	out = static_cast<unsigned char *>(xmalloc(length));
+	out = new unsigned char[length];
 	out[length - 1] = '\0';
 	out_p = &out[0];
 
 	if (i2o_ECPublicKey(key, &out_p) < 0) {
-		free(out);
+		delete[] out;
 		return NULL;
 	}
 
@@ -249,7 +249,7 @@ sasl_pubkey(void)
 			throw std::runtime_error("encode length error");
 		}
 
-		encoded_blob = static_cast<char *>(xmalloc(encode_len));
+		encoded_blob = new char[encode_len];
 		encoded_blob[encode_len - 1] = '\0';
 
 		if ((encode_ret = b64_encode(blob, static_cast<size_t>(length),
@@ -260,6 +260,8 @@ sasl_pubkey(void)
 		msg = strdup_printf("public key is: %s", encoded_blob);
 		output_message(false, msg);
 		free(msg);
+	} catch (const std::bad_alloc &e) {
+		err_exit(ENOMEM, "%s: error: %s", __func__, e.what());
 	} catch (const std::runtime_error &e) {
 		output_message(true, e.what());
 	} catch (...) {
@@ -270,8 +272,8 @@ sasl_pubkey(void)
 		EC_KEY_free(key);
 	if (fp != NULL)
 		(void) fclose(fp);
-	free(encoded_blob);
-	free(blob);
+	delete[] encoded_blob;
+	delete[] blob;
 }
 
 static bool
@@ -572,11 +574,11 @@ sign_decoded_data(EC_KEY *key, const uint8_t *data, int datalen, uint8_t **sig,
 		return false;
 	}
 
-	*sig = static_cast<uint8_t *>(xmalloc(len));
+	*sig = new uint8_t[len];
 	(*sig)[len - 1] = '\0';
 
 	if (!ECDSA_sign(0, data, datalen, *sig, &len, key)) {
-		free(*sig);
+		delete[] *sig;
 		*sig = NULL;
 		*siglen = 0;
 		return false;
@@ -616,8 +618,8 @@ clean_up(EC_KEY *key, FILE *fp, char *out, uint8_t *decoded_chl, uint8_t *sig)
 	if (fp != NULL && fclose(fp) != 0)
 		err_log(errno, "solve_ecdsa_nist256p_challenge: fclose");
 	free(out);
-	free(decoded_chl);
-	free(sig);
+	delete[] decoded_chl;
+	delete[] sig;
 }
 
 char *
@@ -656,7 +658,7 @@ solve_ecdsa_nist256p_challenge(const char *challenge, char **err_reason)
 		    crypt_get_base64_decode_length(challenge)) <= 0)
 			throw std::runtime_error("decode length error");
 
-		decoded_chl = static_cast<uint8_t *>(xmalloc(decode_len));
+		decoded_chl = new uint8_t[decode_len];
 		decoded_chl[decode_len - 1] = '\0';
 
 		if ((decode_ret = b64_decode(challenge, decoded_chl, static_cast
@@ -675,6 +677,8 @@ solve_ecdsa_nist256p_challenge(const char *challenge, char **err_reason)
 		if (b64_encode(sig, siglen, out, static_cast<size_t>
 		    (encode_len)) == -1)
 			throw std::runtime_error("encoding error");
+	} catch (const std::bad_alloc &e) {
+		err_exit(ENOMEM, "%s: error: %s", __func__, e.what());
 	} catch (const std::runtime_error &e) {
 		clean_up(key, fp, out, decoded_chl, sig);
 		*err_reason = sw_strdup(e.what());
