@@ -80,6 +80,7 @@
 #include "commands/squery.h"
 #include "commands/theme.h"
 #include "commands/topic.h"
+#include "commands/utctime.h"
 #include "commands/voice.h"
 #include "commands/wholeft.h"
 #include "commands/znc.h"
@@ -149,6 +150,7 @@ static struct cmds_tag {
 	{ "nickserv",    cmd_nickserv,    true,  nickserv_usage,    ARRAY_SIZE(nickserv_usage),    true  },
 	{ "notice",      cmd_notice,      true,  notice_usage,      ARRAY_SIZE(notice_usage),      true  },
 	{ "ns",          cmd_nickserv,    true,  nickserv_usage,    ARRAY_SIZE(nickserv_usage),    true  },
+	{ "nsid",        cmd_nsid,        true,  nsid_usage,        ARRAY_SIZE(nsid_usage),        true  },
 	{ "op",          cmd_op,          true,  op_usage,          ARRAY_SIZE(op_usage),          true  },
 	{ "oper",        cmd_oper,        true,  oper_usage,        ARRAY_SIZE(oper_usage),        true  },
 	{ "p",           cmd_part,        true,  part_usage,        ARRAY_SIZE(part_usage),        true  },
@@ -173,6 +175,7 @@ static struct cmds_tag {
 	{ "topic",       cmd_topic,       true,  topic_usage,       ARRAY_SIZE(topic_usage),       false },
 	{ "unban",       cmd_unban,       true,  unban_usage,       ARRAY_SIZE(unban_usage),       true  },
 	{ "unignore",    cmd_unignore,    false, unignore_usage,    ARRAY_SIZE(unignore_usage),    false },
+	{ "utctime",     cmd_utctime,     false, utctime_usage,     ARRAY_SIZE(utctime_usage),     false },
 	{ "version",     cmd_version,     true,  version_usage,     ARRAY_SIZE(version_usage),     true  },
 	{ "voice",       cmd_voice,       true,  voice_usage,       ARRAY_SIZE(voice_usage),       true  },
 	{ "wallops",     cmd_wallops,     true,  wallops_usage,     ARRAY_SIZE(wallops_usage),     true  },
