@@ -1,5 +1,5 @@
 /* main.cpp  --  starts execution
-   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -37,6 +37,11 @@
 #include <sys/time.h>
 #endif
 
+#include <openssl/opensslv.h>
+#ifndef OPENSSL_VERSION_TEXT
+#define OPENSSL_VERSION_TEXT "Unknown"
+#endif
+
 #include <locale.h>
 
 #if UNIX
@@ -88,8 +93,8 @@
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.5.6";
-chararray_t	g_swircYear	= "2012-2025";
+chararray_t	g_swircVersion	= "v3.5.7";
+chararray_t	g_swircYear	= "2012-2026";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
 
@@ -247,6 +252,10 @@ view_version()
 	PUTS(MessageVersion);
 	free(MessageVersion);
 
+	write_to_stream(stdout, "--\n");
+	write_to_stream(stdout, "Curses version: %s\n", curses_version());
+	write_to_stream(stdout, "TLS library:    %s\n", OPENSSL_VERSION_TEXT);
+
 	while (true) {
 		char	answer[100] = { '\0' };
 		int	c;
@@ -847,6 +856,64 @@ locale_info::~locale_info()
 	free(this->codeset);
 }
 
+/*
+ * Copy assignment operator
+ */
+locale_info &locale_info::operator=(const locale_info &obj)
+{
+	if (&obj == this)
+		return *this;
+	if (obj.lang_and_territory)
+		this->lang_and_territory = sw_strdup(obj.lang_and_territory);
+	if (obj.codeset)
+		this->codeset = sw_strdup(obj.codeset);
+	return *this;
+}
+
+/*
+ * Copy constructor
+ */
+locale_info::locale_info(const locale_info &obj)
+    : lang_and_territory(nullptr)
+    , codeset(nullptr)
+{
+	if (obj.lang_and_territory)
+		this->lang_and_territory = sw_strdup(obj.lang_and_territory);
+	if (obj.codeset)
+		this->codeset = sw_strdup(obj.codeset);
+}
+
+/*
+ * Move assignment operator
+ */
+locale_info &locale_info::operator=(locale_info &&obj)
+{
+	if (&obj == this)
+		return *this;
+
+	free(this->lang_and_territory);
+	free(this->codeset);
+
+	this->lang_and_territory = obj.lang_and_territory;
+	this->codeset = obj.codeset;
+
+	obj.lang_and_territory = nullptr;
+	obj.codeset = nullptr;
+
+	return *this;
+}
+
+/*
+ * Move constructor
+ */
+locale_info::locale_info(locale_info &&obj)
+    : lang_and_territory(obj.lang_and_territory)
+    , codeset(obj.codeset)
+{
+	obj.lang_and_territory = nullptr;
+	obj.codeset = nullptr;
+}
+
 /**
  * Free locale info
  */
@@ -868,6 +935,126 @@ cmdline_opt_values::~cmdline_opt_values()
 	free(this->config_file);
 }
 
+/*
+ * Copy assignment operator
+ */
+cmdline_opt_values &cmdline_opt_values::operator=(const cmdline_opt_values &obj)
+{
+	if (&obj == this)
+		return *this;
+
+	if (obj.server)
+		this->server = sw_strdup(obj.server);
+	if (obj.port)
+		this->port = sw_strdup(obj.port);
+	if (obj.passwd)
+		this->passwd = sw_strdup(obj.passwd);
+	if (obj.nickname)
+		this->nickname = sw_strdup(obj.nickname);
+	if (obj.username)
+		this->username = sw_strdup(obj.username);
+	if (obj.rl_name)
+		this->rl_name = sw_strdup(obj.rl_name);
+	if (obj.hostname)
+		this->hostname = sw_strdup(obj.hostname);
+	if (obj.config_file)
+		this->config_file = sw_strdup(obj.config_file);
+
+	return *this;
+}
+
+/*
+ * Copy constructor
+ */
+cmdline_opt_values::cmdline_opt_values(const cmdline_opt_values &obj)
+    : server(nullptr)
+    , port(nullptr)
+    , passwd(nullptr)
+    , nickname(nullptr)
+    , username(nullptr)
+    , rl_name(nullptr)
+    , hostname(nullptr)
+    , config_file(nullptr)
+{
+	if (obj.server)
+		this->server = sw_strdup(obj.server);
+	if (obj.port)
+		this->port = sw_strdup(obj.port);
+	if (obj.passwd)
+		this->passwd = sw_strdup(obj.passwd);
+	if (obj.nickname)
+		this->nickname = sw_strdup(obj.nickname);
+	if (obj.username)
+		this->username = sw_strdup(obj.username);
+	if (obj.rl_name)
+		this->rl_name = sw_strdup(obj.rl_name);
+	if (obj.hostname)
+		this->hostname = sw_strdup(obj.hostname);
+	if (obj.config_file)
+		this->config_file = sw_strdup(obj.config_file);
+}
+
+/*
+ * Move assignment operator
+ */
+cmdline_opt_values &cmdline_opt_values::operator=(cmdline_opt_values &&obj)
+{
+	if (&obj == this)
+		return *this;
+
+	free(this->server);
+	free(this->port);
+	free(this->passwd);
+	free(this->nickname);
+	free(this->username);
+	free(this->rl_name);
+	free(this->hostname);
+	free(this->config_file);
+
+	this->server	  = obj.server;
+	this->port	  = obj.port;
+	this->passwd	  = obj.passwd;
+	this->nickname	  = obj.nickname;
+	this->username	  = obj.username;
+	this->rl_name	  = obj.rl_name;
+	this->hostname	  = obj.hostname;
+	this->config_file = obj.config_file;
+
+	obj.server =
+	obj.port =
+	obj.passwd =
+	obj.nickname =
+	obj.username =
+	obj.rl_name =
+	obj.hostname =
+	obj.config_file = nullptr;
+
+	return *this;
+}
+
+/*
+ * Move constructor
+ */
+cmdline_opt_values::cmdline_opt_values(cmdline_opt_values &&obj)
+    : server(obj.server)
+    , port(obj.port)
+    , passwd(obj.passwd)
+    , nickname(obj.nickname)
+    , username(obj.username)
+    , rl_name(obj.rl_name)
+    , hostname(obj.hostname)
+    , config_file(obj.config_file)
+{
+	obj.server =
+	obj.port =
+	obj.passwd =
+	obj.nickname =
+	obj.username =
+	obj.rl_name =
+	obj.hostname =
+	obj.config_file = nullptr;
+}
+
 /**
  * Command-line options destroy
  */
